<a id="types-aiobotocore-events"></a>

# types-aiobotocore-events

[![PyPI - types-aiobotocore-events](https://img.shields.io/pypi/v/types-aiobotocore-events.svg?color=blue)](https://pypi.org/project/types-aiobotocore-events)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/types-aiobotocore-events.svg?color=blue)](https://pypi.org/project/types-aiobotocore-events)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/types-aiobotocore-events?color=blue)](https://pypistats.org/packages/types-aiobotocore-events)

![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)

Type annotations for
[aiobotocore.EventBridge 2.3.3](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/events.html#EventBridge)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 7.6.1](https://github.com/youtype/mypy_boto3_builder).

More information can be found on
[types-aiobotocore](https://pypi.org/project/types-aiobotocore/) page and in
[types-aiobotocore-events docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_events/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/youtype/mypy_boto3_builder/raw/main/demo.gif)

- [types-aiobotocore-events](#types-aiobotocore-events)
  - [How to install](#how-to-install)
    - [VSCode extension](#vscode-extension)
    - [From PyPI with pip](#from-pypi-with-pip)
  - [How to uninstall](#how-to-uninstall)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Emacs](#emacs)
    - [Sublime Text](#sublime-text)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)

<a id="how-to-install"></a>

## How to install

<a id="vscode-extension"></a>

### VSCode extension

Add
[AWS Boto3](https://marketplace.visualstudio.com/items?itemName=Boto3typed.boto3-ide)
extension to your VSCode and run `AWS boto3: Quick Start` command.

Click `Modify` and select `boto3 common` and `EventBridge`.

<a id="from-pypi-with-pip"></a>

### From PyPI with pip

Install `types-aiobotocore` for `EventBridge` service.

```bash
# install with aiobotocore type annotations
python -m pip install 'types-aiobotocore[events]'


# Lite version does not provide session.client/resource overloads
# it is more RAM-friendly, but requires explicit type annotations
python -m pip install 'types-aiobotocore-lite[events]'


# standalone installation
python -m pip install types-aiobotocore-events
```

<a id="how-to-uninstall"></a>

## How to uninstall

```bash
python -m pip uninstall -y types-aiobotocore-events
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `types-aiobotocore[events]` in your environment:

```bash
python -m pip install 'types-aiobotocore[events]'
```

Both type checking and code completion should now work. No explicit type
annotations required, write your `aiobotocore` code as usual.

<a id="pycharm"></a>

### PyCharm

Install `types-aiobotocore-lite[events]` in your environment:

```bash
python -m pip install 'types-aiobotocore-lite[events]'`
```

Both type checking and code completion should now work. Explicit type
annotations **are required**.

Use `types-aiobotocore` package instead for implicit type discovery.

<a id="emacs"></a>

### Emacs

- Install `types-aiobotocore` with services you use in your environment:

```bash
python -m pip install 'types-aiobotocore[events]'
```

- Install [use-package](https://github.com/jwiegley/use-package),
  [lsp](https://github.com/emacs-lsp/lsp-mode/),
  [company](https://github.com/company-mode/company-mode) and
  [flycheck](https://github.com/flycheck/flycheck) packages
- Install [lsp-pyright](https://github.com/emacs-lsp/lsp-pyright) package

```elisp
(use-package lsp-pyright
  :ensure t
  :hook (python-mode . (lambda ()
                          (require 'lsp-pyright)
                          (lsp)))  ; or lsp-deferred
  :init (when (executable-find "python3")
          (setq lsp-pyright-python-executable-cmd "python3"))
  )
```

- Make sure emacs uses the environment where you have installed
  `types-aiobotocore`

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="sublime-text"></a>

### Sublime Text

- Install `types-aiobotocore[events]` with services you use in your
  environment:

```bash
python -m pip install 'types-aiobotocore[events]'
```

- Install [LSP-pyright](https://github.com/sublimelsp/LSP-pyright) package

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `types-aiobotocore[events]` in your environment:

```bash
python -m pip install 'types-aiobotocore[events]'`
```

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `npm i -g pyright`
- Install `types-aiobotocore[events]` in your environment:

```bash
python -m pip install 'types-aiobotocore[events]'
```

Optionally, you can install `types-aiobotocore` to `typings` folder.

Type checking should now work. No explicit type annotations required, write
your `aiobotocore` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`EventBridgeClient` provides annotations for `session.create_client("events")`.

```python
from aiobotocore.session import get_session

from types_aiobotocore_events import EventBridgeClient

session = get_session()
async with session.create_client("events") as client:
    client: EventBridgeClient
    # now client usage is checked by mypy and IDE should provide code completion
```

<a id="paginators-annotations"></a>

### Paginators annotations

`types_aiobotocore_events.paginator` module contains type annotations for all
paginators.

````python
from aiobotocore.session import get_session

from types_aiobotocore_events import EventBridgeClient
from types_aiobotocore_events.paginator import (
    ListRuleNamesByTargetPaginator,
    ListRulesPaginator,
    ListTargetsByRulePaginator,
)

session = get_session()
async with session.create_client("events") as client:
    client: EventBridgeClient

    # Explicit type annotations are optional here
    # Type should be correctly discovered by mypy and IDEs
    # VSCode requires explicit type annotations
        list_rule_names_by_target_paginator: ListRuleNamesByTargetPaginator = client.get_paginator("list_rule_names_by_target")
        list_rules_paginator: ListRulesPaginator = client.get_paginator("list_rules")
        list_targets_by_rule_paginator: ListTargetsByRulePaginator = client.get_paginator("list_targets_by_rule")
    ```







### Literals

`types_aiobotocore_events.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from types_aiobotocore_events.literals import (
    ApiDestinationHttpMethodType,
    ApiDestinationStateType,
    ArchiveStateType,
    AssignPublicIpType,
    ConnectionAuthorizationTypeType,
    ConnectionOAuthHttpMethodType,
    ConnectionStateType,
    EventSourceStateType,
    LaunchTypeType,
    ListRuleNamesByTargetPaginatorName,
    ListRulesPaginatorName,
    ListTargetsByRulePaginatorName,
    PlacementConstraintTypeType,
    PlacementStrategyTypeType,
    PropagateTagsType,
    ReplayStateType,
    RuleStateType,
    EventBridgeServiceName,
    ServiceName,
    ResourceServiceName,
    PaginatorName,
    RegionName,
)

def check_value(value: ApiDestinationHttpMethodType) -> bool:
    ...
````

### Typed dictionaries

`types_aiobotocore_events.type_defs` module contains structures and shapes
assembled to typed dictionaries for additional type checking.

```python
from types_aiobotocore_events.type_defs import (
    ActivateEventSourceRequestRequestTypeDef,
    ApiDestinationTypeDef,
    ArchiveTypeDef,
    AwsVpcConfigurationTypeDef,
    BatchArrayPropertiesTypeDef,
    BatchRetryStrategyTypeDef,
    CancelReplayRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    CapacityProviderStrategyItemTypeDef,
    ConditionTypeDef,
    ConnectionApiKeyAuthResponseParametersTypeDef,
    ConnectionBasicAuthResponseParametersTypeDef,
    ConnectionBodyParameterTypeDef,
    ConnectionHeaderParameterTypeDef,
    ConnectionQueryStringParameterTypeDef,
    ConnectionOAuthClientResponseParametersTypeDef,
    ConnectionTypeDef,
    CreateApiDestinationRequestRequestTypeDef,
    CreateArchiveRequestRequestTypeDef,
    CreateConnectionApiKeyAuthRequestParametersTypeDef,
    CreateConnectionBasicAuthRequestParametersTypeDef,
    CreateConnectionOAuthClientRequestParametersTypeDef,
    TagTypeDef,
    CreatePartnerEventSourceRequestRequestTypeDef,
    DeactivateEventSourceRequestRequestTypeDef,
    DeadLetterConfigTypeDef,
    DeauthorizeConnectionRequestRequestTypeDef,
    DeleteApiDestinationRequestRequestTypeDef,
    DeleteArchiveRequestRequestTypeDef,
    DeleteConnectionRequestRequestTypeDef,
    DeleteEventBusRequestRequestTypeDef,
    DeletePartnerEventSourceRequestRequestTypeDef,
    DeleteRuleRequestRequestTypeDef,
    DescribeApiDestinationRequestRequestTypeDef,
    DescribeArchiveRequestRequestTypeDef,
    DescribeConnectionRequestRequestTypeDef,
    DescribeEventBusRequestRequestTypeDef,
    DescribeEventSourceRequestRequestTypeDef,
    DescribePartnerEventSourceRequestRequestTypeDef,
    DescribeReplayRequestRequestTypeDef,
    ReplayDestinationTypeDef,
    DescribeRuleRequestRequestTypeDef,
    DisableRuleRequestRequestTypeDef,
    PlacementConstraintTypeDef,
    PlacementStrategyTypeDef,
    EnableRuleRequestRequestTypeDef,
    EventBusTypeDef,
    EventSourceTypeDef,
    HttpParametersTypeDef,
    InputTransformerTypeDef,
    KinesisParametersTypeDef,
    ListApiDestinationsRequestRequestTypeDef,
    ListArchivesRequestRequestTypeDef,
    ListConnectionsRequestRequestTypeDef,
    ListEventBusesRequestRequestTypeDef,
    ListEventSourcesRequestRequestTypeDef,
    ListPartnerEventSourceAccountsRequestRequestTypeDef,
    PartnerEventSourceAccountTypeDef,
    ListPartnerEventSourcesRequestRequestTypeDef,
    PartnerEventSourceTypeDef,
    ListReplaysRequestRequestTypeDef,
    ReplayTypeDef,
    PaginatorConfigTypeDef,
    ListRuleNamesByTargetRequestRequestTypeDef,
    ListRulesRequestRequestTypeDef,
    RuleTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTargetsByRuleRequestRequestTypeDef,
    PutEventsRequestEntryTypeDef,
    PutEventsResultEntryTypeDef,
    PutPartnerEventsRequestEntryTypeDef,
    PutPartnerEventsResultEntryTypeDef,
    PutTargetsResultEntryTypeDef,
    RedshiftDataParametersTypeDef,
    RemovePermissionRequestRequestTypeDef,
    RemoveTargetsRequestRequestTypeDef,
    RemoveTargetsResultEntryTypeDef,
    RetryPolicyTypeDef,
    RunCommandTargetTypeDef,
    SageMakerPipelineParameterTypeDef,
    SqsParametersTypeDef,
    TestEventPatternRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateApiDestinationRequestRequestTypeDef,
    UpdateArchiveRequestRequestTypeDef,
    UpdateConnectionApiKeyAuthRequestParametersTypeDef,
    UpdateConnectionBasicAuthRequestParametersTypeDef,
    UpdateConnectionOAuthClientRequestParametersTypeDef,
    NetworkConfigurationTypeDef,
    BatchParametersTypeDef,
    CancelReplayResponseTypeDef,
    CreateApiDestinationResponseTypeDef,
    CreateArchiveResponseTypeDef,
    CreateConnectionResponseTypeDef,
    CreateEventBusResponseTypeDef,
    CreatePartnerEventSourceResponseTypeDef,
    DeauthorizeConnectionResponseTypeDef,
    DeleteConnectionResponseTypeDef,
    DescribeApiDestinationResponseTypeDef,
    DescribeArchiveResponseTypeDef,
    DescribeEventBusResponseTypeDef,
    DescribeEventSourceResponseTypeDef,
    DescribePartnerEventSourceResponseTypeDef,
    DescribeRuleResponseTypeDef,
    EmptyResponseMetadataTypeDef,
    ListApiDestinationsResponseTypeDef,
    ListArchivesResponseTypeDef,
    ListRuleNamesByTargetResponseTypeDef,
    PutRuleResponseTypeDef,
    StartReplayResponseTypeDef,
    TestEventPatternResponseTypeDef,
    UpdateApiDestinationResponseTypeDef,
    UpdateArchiveResponseTypeDef,
    UpdateConnectionResponseTypeDef,
    PutPermissionRequestRequestTypeDef,
    ConnectionHttpParametersTypeDef,
    ListConnectionsResponseTypeDef,
    CreateEventBusRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    PutRuleRequestRequestTypeDef,
    TagResourceRequestRequestTypeDef,
    DescribeReplayResponseTypeDef,
    StartReplayRequestRequestTypeDef,
    ListEventBusesResponseTypeDef,
    ListEventSourcesResponseTypeDef,
    ListPartnerEventSourceAccountsResponseTypeDef,
    ListPartnerEventSourcesResponseTypeDef,
    ListReplaysResponseTypeDef,
    ListRuleNamesByTargetRequestListRuleNamesByTargetPaginateTypeDef,
    ListRulesRequestListRulesPaginateTypeDef,
    ListTargetsByRuleRequestListTargetsByRulePaginateTypeDef,
    ListRulesResponseTypeDef,
    PutEventsRequestRequestTypeDef,
    PutEventsResponseTypeDef,
    PutPartnerEventsRequestRequestTypeDef,
    PutPartnerEventsResponseTypeDef,
    PutTargetsResponseTypeDef,
    RemoveTargetsResponseTypeDef,
    RunCommandParametersTypeDef,
    SageMakerPipelineParametersTypeDef,
    EcsParametersTypeDef,
    ConnectionOAuthResponseParametersTypeDef,
    CreateConnectionOAuthRequestParametersTypeDef,
    UpdateConnectionOAuthRequestParametersTypeDef,
    TargetTypeDef,
    ConnectionAuthResponseParametersTypeDef,
    CreateConnectionAuthRequestParametersTypeDef,
    UpdateConnectionAuthRequestParametersTypeDef,
    ListTargetsByRuleResponseTypeDef,
    PutTargetsRequestRequestTypeDef,
    DescribeConnectionResponseTypeDef,
    CreateConnectionRequestRequestTypeDef,
    UpdateConnectionRequestRequestTypeDef,
)

def get_structure() -> ActivateEventSourceRequestRequestTypeDef:
    return {
      ...
    }
```

## How it works

Fully automated
[mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder) carefully
generates type annotations for each service, patiently waiting for
`aiobotocore` updates. It delivers a drop-in type annotations for you and makes
sure that:

- All available `aiobotocore` services are covered.
- Each public class and method of every `aiobotocore` service gets valid type
  annotations extracted from the documentation (blame `botocore` docs if types
  are incorrect).
- Type annotations include up-to-date documentation.
- Link to documentation is provided for every method.
- Code is processed by [black](https://github.com/psf/black) and
  [isort](https://github.com/PyCQA/isort) for readability.

## What's new

### Implemented features

- Fully type annotated `boto3`, `botocore` and `aiobotocore` libraries
- `mypy`, `pyright`, `VSCode`, `PyCharm`, `Sublime Text` and `Emacs`
  compatibility
- `Client`, `ServiceResource`, `Resource`, `Waiter` `Paginator` type
  annotations for each service
- Generated `TypeDefs` for each service
- Generated `Literals` for each service
- Auto discovery of types for `boto3.client` and `boto3.session` calls
- Auto discovery of types for `session.client` and `session.session` calls
- Auto discovery of types for `client.get_waiter` and `client.get_paginator`
  calls
- Auto discovery of types for `ServiceResource` and `Resource` collections
- Auto discovery of types for `aiobotocore.Session.create_client` calls

### Latest changes

Builder changelog can be found in
[Releases](https://github.com/youtype/mypy_boto3_builder/releases).

## Versioning

`types-aiobotocore-events` version is the same as related `aiobotocore` version
and follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

## Thank you

- [Allie Fitter](https://github.com/alliefitter) for
  [boto3-type-annotations](https://pypi.org/project/boto3-type-annotations/),
  this package is based on top of his work
- [black](https://github.com/psf/black) developers for an awesome formatting
  tool
- [Timothy Edmund Crosley](https://github.com/timothycrosley) for
  [isort](https://github.com/PyCQA/isort) and how flexible it is
- [mypy](https://github.com/python/mypy) developers for doing all dirty work
  for us
- [pyright](https://github.com/microsoft/pyright) team for the new era of typed
  Python

## Documentation

All services type annotations can be found in
[aiobotocore docs](https://youtype.github.io/types_aiobotocore_docs/types_aiobotocore_events/)

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/youtype/mypy_boto3_builder/issues/)
repository.
